@@ -16,16 +16,17 @@ from django.http import (
 )
 from django.shortcuts import get_list_or_404, get_object_or_404, render
 from django.template.response import TemplateResponse
-from django.utils import six
-from django.utils.six.moves.urllib.parse import parse_qsl, urlparse
 from django.utils.decorators import method_decorator
 from django.utils.encoding import force_text
-from django.utils.html import conditional_escape
 from django.utils import translation
 from django.utils.translation import ugettext as _
 from django.views.decorators.clickjacking import xframe_options_sameorigin
 from django.views.decorators.http import require_POST
 
+from six.moves.urllib.parse import parse_qsl, urlparse
+
+from six import get_unbound_function, get_method_function
+
 from cms import operations
 from cms.admin.forms import PluginAddValidationForm
 from cms.constants import SLUG_REGEXP
@@ -69,7 +70,7 @@ def _instance_overrides_method(base, instance, method_name):
     """
     bound_method = getattr(instance, method_name)
     unbound_method = getattr(base, method_name)
-    return six.get_unbound_function(unbound_method) != six.get_method_function(bound_method)
+    return get_unbound_function(unbound_method) != get_method_function(bound_method)
 
 
 class FrontendEditableAdminMixin(object):
@@ -303,7 +304,7 @@ class PlaceholderAdminMixin(object):
             # errors is s dict mapping fields to a list of errors
             # for that field.
             error = list(form.errors.values())[0][0]
-            return HttpResponseBadRequest(conditional_escape(force_text(error)))
+            return HttpResponseBadRequest(force_text(error))
 
         plugin_data = form.cleaned_data
         placeholder = plugin_data['placeholder_id']
