@@ -16,9 +16,10 @@ from django.core.exceptions import ValidationError
 from django.db import transaction
 from django.template.defaultfilters import slugify
 from django.template.loader import get_template
-from django.utils import six
 from django.utils.translation import activate
 
+from six import string_types
+
 from cms import constants
 from cms.app_base import CMSApp
 from cms.apphook_pool import apphook_pool
@@ -58,7 +59,7 @@ def _verify_apphook(apphook, namespace):
         apphook_name = apphook.__class__.__name__
     elif hasattr(apphook, '__module__') and issubclass(apphook, CMSApp):
         return apphook.__name__
-    elif isinstance(apphook, six.string_types):
+    elif isinstance(apphook, string_types):
         try:
             assert apphook in apphook_pool.apps
         except AssertionError:
@@ -82,7 +83,7 @@ def _verify_plugin_type(plugin_type):
         plugin_model = plugin_type.model
         assert plugin_type in plugin_pool.plugins.values()
         plugin_type = plugin_type.__name__
-    elif isinstance(plugin_type, six.string_types):
+    elif isinstance(plugin_type, string_types):
         try:
             plugin_model = plugin_pool.get_plugin(plugin_type).model
         except KeyError:
