@@ -5,10 +5,11 @@ from importlib import import_module
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.db import OperationalError, ProgrammingError
-from django.utils import six
 from django.utils.translation import get_language, override
 from django.urls import Resolver404, reverse
 
+from six import string_types
+
 from cms.apphook_pool import apphook_pool
 from cms.models.pagemodel import Page
 from cms.utils import get_current_site
@@ -59,20 +60,28 @@ def applications_page_check(request, current_page=None, path=None):
             pass
     return None
 
-
 class AppRegexURLResolver(URLResolver):
+
     def __init__(self, *args, **kwargs):
         self.page_id = None
         self.url_patterns_dict = {}
         super(AppRegexURLResolver, self).__init__(*args, **kwargs)
 
+    @property
+    def urlconf_module(self):
+        # It is valid for urlconf_module to be a list of patterns. So we just
+        # return the list here.
+        #
+        # See https://github.com/django/django/blob/2.2.4/django/urls/resolvers.py#L578
+        #
+        return self.url_patterns_dict.get(get_language(), [])
+
+    # On URLResolver the url_patterns property is cached and thus calls made after
+    # language changes (different return values for get_language()) would not return the
+    # right value. Overriding here prevents caching.
     @property
     def url_patterns(self):
-        language = get_language()
-        if language in self.url_patterns_dict:
-            return self.url_patterns_dict[language]
-        else:
-            return []
+        return self.urlconf_module
 
     def resolve_page_id(self, path):
         """Resolves requested path similar way how resolve does, but instead
@@ -141,7 +150,7 @@ def recurse_patterns(path, pattern_list, page_id, default_args=None,
 
             regex_pattern = regex
             if not DJANGO_1_11:
-                regex_pattern = RegexPattern(regex, name=pattern.name)
+                regex_pattern = RegexPattern(regex, name=pattern.name, is_endpoint=True)
             resolver = URLPattern(regex_pattern, pattern.callback, args,
                                   pattern.name)
         resolver.page_id = page_id
@@ -162,7 +171,7 @@ def _set_permissions(patterns, exclude_permissions):
 
 def get_app_urls(urls):
     for urlconf in urls:
-        if isinstance(urlconf, six.string_types):
+        if isinstance(urlconf, string_types):
             mod = import_module(urlconf)
             if not hasattr(mod, 'urlpatterns'):
                 raise ImproperlyConfigured(
