@@ -10,12 +10,13 @@ from django.db import models
 from django.db.models import ManyToManyField, Model
 from django.db.models.base import ModelBase
 from django.urls import NoReverseMatch
-from django.utils import six, timezone
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils import timezone
+from django.utils.encoding import force_text
 from django.utils.safestring import mark_safe
-from django.utils.six import text_type
 from django.utils.translation import ugettext_lazy as _
 
+from six import text_type, with_metaclass, python_2_unicode_compatible
+
 from cms.exceptions import DontUsePageAttributeWarning
 from cms.models.placeholdermodel import Placeholder
 from cms.utils.conf import get_cms_setting
@@ -92,7 +93,7 @@ class PluginModelBase(ModelBase):
 
 
 @python_2_unicode_compatible
-class CMSPlugin(six.with_metaclass(PluginModelBase, MP_Node)):
+class CMSPlugin(with_metaclass(PluginModelBase, MP_Node)):
     '''
     The base class for a CMS plugin model. When defining a new custom plugin, you should
     store plugin-instance specific information on a subclass of this class.
