@@ -1,13 +1,10 @@
 from cms.menu_bases import CMSAttachMenu
 from cms.test_utils.project.sampleapp.models import Category
+from django.urls import reverse, NoReverseMatch
 from django.utils.translation import ugettext_lazy as _
 from menus.base import Menu, NavigationNode
 from menus.menu_pool import menu_pool
 
-try:
-    from django.urls import reverse, NoReverseMatch
-except ImportError:
-    from django.core.urlresolvers import reverse, NoReverseMatch
 
 class SampleAppMenu(Menu):
 
