@@ -1,18 +1,22 @@
 # -*- coding: utf-8 -*-
 import sys
+import mock
 
 from django.contrib.admin.models import CHANGE, LogEntry
 from django.contrib.auth import get_user_model
 from django.contrib.auth.models import Permission
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.sites.models import Site
+from django.core import checks
 from django.core.cache import cache
+from django.core.checks.urls import check_url_config
 from django.test.utils import override_settings
 from django.urls import NoReverseMatch, clear_url_caches, resolve, reverse
-from django.utils import six
 from django.utils.timezone import now
 from django.utils.translation import override as force_language
 
+from six import string_types
+
 from cms.admin.forms import AdvancedSettingsForm
 from cms.api import create_page, create_title
 from cms.app_base import CMSApp
@@ -113,7 +117,7 @@ class ApphooksTestCase(CMSTestCase):
         # publisher_public is set to draft on publish, issue with onetoone reverse
         child_child_page = self.reload(child_child_page)
 
-        if isinstance(title_langs, six.string_types):
+        if isinstance(title_langs, string_types):
             titles = child_child_page.publisher_public.get_title_obj(title_langs)
         else:
             titles = [child_child_page.publisher_public.get_title_obj(l) for l in title_langs]
@@ -122,6 +126,15 @@ class ApphooksTestCase(CMSTestCase):
 
         return titles
 
+    @override_settings(ROOT_URLCONF='cms.test_utils.project.fourth_urls_for_apphook_tests')
+    def test_check_url_config(self):
+        """
+        Test for urls config check.
+        """
+        self.apphook_clear()
+        result = check_url_config(None)
+        self.assertEqual(len(result), 0)
+
     @override_settings(CMS_APPHOOKS=['%s.%s' % (APP_MODULE, APP_NAME)])
     def test_explicit_apphooks(self):
         """
@@ -172,6 +185,17 @@ class ApphooksTestCase(CMSTestCase):
 
         self.apphook_clear()
 
+    @override_settings(ROOT_URLCONF='cms.test_utils.project.urls_for_apphook_tests')
+    def test_apphook_does_not_crash_django_checks(self):
+        # This test case reproduced the situation causing the error reported in issue #6717.
+        self.apphook_clear()
+        superuser = get_user_model().objects.create_superuser('admin', 'admin@admin.com', 'admin')
+        create_page("apphooked-page", "nav_playground.html", "en",
+                    created_by=superuser, published=True, apphook="SampleApp")
+        self.reload_urls()
+        checks.run_checks()
+        self.apphook_clear()
+
     @override_settings(ROOT_URLCONF='cms.test_utils.project.urls_for_apphook_tests')
     def test_apphook_on_root_reverse(self):
         self.apphook_clear()
@@ -855,7 +879,8 @@ class ApphooksTestCase(CMSTestCase):
 
         request = self.get_request('/')
         renderer = menu_pool.get_renderer(request)
-        nodes = renderer.get_nodes()
+        with mock.patch("menus.menu_pool.logger.error"):
+            nodes = renderer.get_nodes()
         nodes_urls = [node.url for node in nodes]
         self.assertTrue(reverse('sample-account') in nodes_urls)
         self.assertFalse('/en/child_page/page2/' in nodes_urls)
