@@ -1,11 +1,14 @@
 # -*- coding: utf-8 -*-
+from django.forms import MediaDefiningClass
+
+from six import with_metaclass
+
 from cms.exceptions import LanguageError
-from cms.utils import get_language_from_request
+from cms.utils import get_current_site, get_language_from_request
 from cms.utils.i18n import get_language_object
-from django.contrib.sites.models import Site
 
 
-class CMSToolbar(object):
+class CMSToolbar(with_metaclass(MediaDefiningClass)):
     supported_apps = None
 
     def __init__(self, request, toolbar, is_current_app, app_path):
@@ -13,7 +16,7 @@ class CMSToolbar(object):
         self.toolbar = toolbar
         self.is_current_app = is_current_app
         self.app_path = app_path
-        self.current_site = Site.objects.get_current()
+        self.current_site = get_current_site()
         try:
             self.current_lang = get_language_object(get_language_from_request(self.request), self.current_site.pk)['code']
         except LanguageError:
@@ -25,9 +28,6 @@ class CMSToolbar(object):
     def post_template_populate(self):
         pass
 
-    def request_hook(self):
-        pass
-
     @classmethod
     def check_current_app(cls, key, app_name):
         if cls.supported_apps is None:
@@ -37,4 +37,4 @@ class CMSToolbar(object):
         for local_app in local_apps:
             if app_name and local_app and app_name.startswith(local_app):
                 return True
-        return False
\ No newline at end of file
+        return False
