@@ -3,63 +3,47 @@
 from django.conf import settings
 from django.core.files.storage import get_storage_class
 from django.utils.functional import LazyObject
-from cms import constants
-from cms.utils.conf import get_cms_setting
+
 from cms.utils.conf import get_site_id  # nopyflakes
 from cms.utils.i18n import get_default_language
 from cms.utils.i18n import get_language_list
 from cms.utils.i18n import get_language_code
 
 
-def get_template_from_request(request, obj=None, no_current_page=False):
-    """
-    Gets a valid template from different sources or falls back to the default
-    template.
-    """
-    template = None
-    if len(get_cms_setting('TEMPLATES')) == 1:
-        return get_cms_setting('TEMPLATES')[0][0]
-    if "template" in request.REQUEST:
-        template = request.REQUEST['template']
-    if not template and obj is not None:
-        template = obj.get_template()
-    if not template and not no_current_page and hasattr(request, "current_page"):
-        current_page = request.current_page
-        if hasattr(current_page, "get_template"):
-            template = current_page.get_template()
-    if template is not None and template in dict(get_cms_setting('TEMPLATES')).keys():
-        if template == constants.TEMPLATE_INHERITANCE_MAGIC and obj:
-            # Happens on admin's request when changing the template for a page
-            # to "inherit".
-            return obj.get_template()
-        return template
-    return get_cms_setting('TEMPLATES')[0][0]
+def get_current_site():
+    from django.contrib.sites.models import Site
+
+    return Site.objects.get_current()
 
 
 def get_language_from_request(request, current_page=None):
     """
     Return the most obvious language according the request
     """
-    language = request.REQUEST.get('language', None)
-    site_id = current_page.site_id if current_page else None
+    language = None
+    if hasattr(request, 'POST'):
+        language = request.POST.get('language', None)
+    if hasattr(request, 'GET') and not language:
+        language = request.GET.get('language', None)
+    site_id = current_page.node.site_id if current_page else None
     if language:
         language = get_language_code(language)
         if not language in get_language_list(site_id):
             language = None
-    if language is None:
+    if not language:
         language = get_language_code(getattr(request, 'LANGUAGE_CODE', None))
     if language:
         if not language in get_language_list(site_id):
             language = None
 
-    if language is None and current_page:
+    if not language and current_page:
         # in last resort, get the first language available in the page
         languages = current_page.get_languages()
 
         if len(languages) > 0:
             language = languages[0]
 
-    if language is None:
+    if not language:
         # language must be defined in CMS_LANGUAGES, so check first if there
         # is any language with LANGUAGE_CODE, otherwise try to split it and find
         # best match
