@@ -3,9 +3,12 @@ from copy import deepcopy
 from collections import defaultdict
 from itertools import groupby, starmap
 from operator import attrgetter, itemgetter
+try:
+    from functools import lru_cache
+except ImportError:
+    from django.utils.lru_cache import lru_cache
 
 from django.utils.encoding import force_text
-from django.utils.lru_cache import lru_cache
 from django.utils.translation import ugettext as _
 
 from cms.exceptions import PluginLimitReached
