@@ -24,7 +24,7 @@ class Marker(Modifier):
                 if selected and not selected.parent:
                     node.sibling = True
                 root_nodes.append(node)
-            if node.selected: 
+            if node.selected:
                 if node.parent:
                     newnode = node
                     while newnode.parent:
@@ -37,7 +37,7 @@ class Marker(Modifier):
                     for root_node in root_nodes:
                         if not root_node.selected:
                             root_node.sibling = True
-                if node.children:                    
+                if node.children:
                     self.mark_descendants(node.children)
                 selected = node
             if node.children:
@@ -45,7 +45,7 @@ class Marker(Modifier):
             else:
                 node.is_leaf_node = True
         return nodes
-                
+
     def mark_descendants(self, nodes):
         for node in nodes:
             node.descendant = True
@@ -58,22 +58,22 @@ class Level(Modifier):
     marks all node levels
     """
     post_cut = True
-    
+
     def modify(self, request, nodes, namespace, root_id, post_cut, breadcrumb):
         if breadcrumb:
             return nodes
         for node in nodes:
-            
+
             if not node.parent:
                 if post_cut:
                     node.menu_level = 0
                 else:
                     node.level = 0
                 self.mark_levels(node, post_cut)
-                
+
         return nodes
-            
-                    
+
+
     def mark_levels(self, node, post_cut):
         for child in node.children:
             if post_cut:
@@ -94,9 +94,9 @@ class AuthVisibility(Modifier):
         final = []
         for node in nodes:
             if (node.attr.get('visible_for_authenticated', True) and \
-                 request.user.is_authenticated()) or \
+                 request.user.is_authenticated) or \
                 (node.attr.get('visible_for_anonymous', True) and \
-                 not request.user.is_authenticated()):
+                 not request.user.is_authenticated):
                 final.append(node)
             else:
                 if node.parent and node in node.parent.children:
@@ -108,4 +108,3 @@ def register():
     menu_pool.register_modifier(Marker)
     menu_pool.register_modifier(AuthVisibility)
     menu_pool.register_modifier(Level)
-    
\ No newline at end of file
